pub trait FailureRecorder {
// Required method
fn record_failure(&self, domain: &str, reason: &str);
}Expand description
Records domain-level mitigation failures without depending on the full state manager.
pub trait FailureRecorder {
// Required method
fn record_failure(&self, domain: &str, reason: &str);
}Records domain-level mitigation failures without depending on the full state manager.